[PATCH v8 08/13] mfd: nct6694: Rename USB transport functions with _usb_ prefix

From: a0282524688

Date: Wed Oct 07 2026 - 06:22:18 EST


From: Ming Yu <a0282524688@xxxxxxxxx>

Add a _usb_ prefix to the USB transport functions, tables and driver
name to mark them as USB specific, in preparation for the core and HIF
transport added in later patches.

Keep nct6694_{read,write}_msg() as static inline wrappers in the shared
header so that the sub-device drivers remain untouched; they are removed
once the regmap-based transport abstraction is in place.

No functional change.

Signed-off-by: Ming Yu <a0282524688@xxxxxxxxx>
---
Changes in v8:
- None.

Changes in v7:
- None.

Changes in v6:
- New patch replacing the v5 function-pointer transport abstraction:
rename the exported I/O functions with an _usb_ prefix and add
transitional inline nct6694_{read,write}_msg() wrappers in the shared
header so sub-device drivers stay untouched in this commit.

drivers/mfd/nct6694.c | 40 ++++++++++++++++++++-----------------
include/linux/mfd/nct6694.h | 22 ++++++++++++++++++--
2 files changed, 42 insertions(+), 20 deletions(-)

diff --git a/include/linux/mfd/nct6694.h b/include/linux/mfd/nct6694.h
index 0ab2bd3bfdc1..61155f9832b0 100644
--- a/include/linux/mfd/nct6694.h
+++ b/include/linux/mfd/nct6694.h
@@ -91,7 +91,25 @@ struct nct6694 {
unsigned int irq_enable;
};

-int nct6694_read_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cmd_hd, void *buf);
-int nct6694_write_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cmd_hd, void *buf);
+int nct6694_usb_read_msg(struct nct6694 *ddata,
+ const struct nct6694_cmd_header *cmd_hd,
+ void *buf);
+int nct6694_usb_write_msg(struct nct6694 *ddata,
+ const struct nct6694_cmd_header *cmd_hd,
+ void *buf);
+
+static inline int nct6694_read_msg(struct nct6694 *ddata,
+ const struct nct6694_cmd_header *cmd_hd,
+ void *buf)
+{
+ return nct6694_usb_read_msg(ddata, cmd_hd, buf);
+}
+
+static inline int nct6694_write_msg(struct nct6694 *ddata,
+ const struct nct6694_cmd_header *cmd_hd,
+ void *buf)
+{
+ return nct6694_usb_write_msg(ddata, cmd_hd, buf);
+}

#endif
diff --git a/drivers/mfd/nct6694.c b/drivers/mfd/nct6694.c
index 6d75b1485350..83e9c7ac9bee 100644
--- a/drivers/mfd/nct6694.c
+++ b/drivers/mfd/nct6694.c
@@ -50,7 +50,7 @@ static struct nct6694_usb_data *to_nct6694_usb_data(struct nct6694 *ddata)
return container_of(ddata, struct nct6694_usb_data, core);
}

-static const struct mfd_cell nct6694_devs[] = {
+static const struct mfd_cell nct6694_usb_devs[] = {
MFD_CELL_NAME("nct6694-gpio"),
MFD_CELL_NAME("nct6694-gpio"),
MFD_CELL_NAME("nct6694-gpio"),
@@ -86,7 +86,7 @@ static const struct mfd_cell nct6694_devs[] = {
MFD_CELL_NAME("nct6694-rtc"),
};

-static int nct6694_response_err_handling(struct nct6694 *ddata, unsigned char err_status)
+static int nct6694_usb_err_handling(struct nct6694 *ddata, unsigned char err_status)
{
switch (err_status) {
case NCT6694_NO_ERROR:
@@ -111,7 +111,7 @@ static int nct6694_response_err_handling(struct nct6694 *ddata, unsigned char er
}

/**
* nct6694_read_msg() - Read message from NCT6694 device
* @ddata: NCT6694 device pointer
* @cmd_hd: command header structure
* @buf: buffer to store the response data
@@ -122,7 +122,9 @@ static int nct6694_response_err_handling(struct nct6694 *ddata, unsigned char er
*
* Return: Negative value on error or 0 on success.
*/
-int nct6694_read_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cmd_hd, void *buf)
+int nct6694_usb_read_msg(struct nct6694 *ddata,
+ const struct nct6694_cmd_header *cmd_hd,
+ void *buf)
{
struct nct6694_usb_data *usb_data = to_nct6694_usb_data(ddata);
union nct6694_usb_hdr *hdr = usb_data->hdr_buf;
@@ -170,12 +172,12 @@ int nct6694_read_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cmd

memcpy(buf, usb_data->data_buf, data_len);

- return nct6694_response_err_handling(ddata, hdr->response_header.sts);
+ return nct6694_usb_err_handling(ddata, hdr->response_header.sts);
}
-EXPORT_SYMBOL_GPL(nct6694_read_msg);
+EXPORT_SYMBOL_GPL(nct6694_usb_read_msg);

/**
* nct6694_write_msg() - Write message to NCT6694 device
* @ddata: NCT6694 device pointer
* @cmd_hd: command header structure
* @buf: buffer containing the data to be sent
@@ -185,7 +187,9 @@ EXPORT_SYMBOL_GPL(nct6694_read_msg);
*
* Return: Negative value on error or 0 on success.
*/
-int nct6694_write_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cmd_hd, void *buf)
+int nct6694_usb_write_msg(struct nct6694 *ddata,
+ const struct nct6694_cmd_header *cmd_hd,
+ void *buf)
{
struct nct6694_usb_data *usb_data = to_nct6694_usb_data(ddata);
union nct6694_usb_hdr *hdr = usb_data->hdr_buf;
@@ -240,11 +244,11 @@ int nct6694_write_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cm

memcpy(buf, usb_data->data_buf, data_len);

- return nct6694_response_err_handling(ddata, hdr->response_header.sts);
+ return nct6694_usb_err_handling(ddata, hdr->response_header.sts);
}
-EXPORT_SYMBOL_GPL(nct6694_write_msg);
+EXPORT_SYMBOL_GPL(nct6694_usb_write_msg);

-static void usb_int_callback(struct urb *urb)
+static void nct6694_usb_int_callback(struct urb *urb)
{
struct nct6694 *ddata = urb->context;
__le32 *status_le = urb->transfer_buffer;
@@ -398,7 +402,7 @@ static int nct6694_usb_probe(struct usb_interface *iface,
int_pipe = usb_rcvintpipe(usb_dev, NCT6694_INT_IN_EP);
usb_fill_int_urb(usb_data->int_urb, usb_dev, int_pipe,
usb_data->int_buf, sizeof(*usb_data->int_buf),
- usb_int_callback, ddata,
+ nct6694_usb_int_callback, ddata,
usb_pipe_endpoint(usb_dev, int_pipe)->desc.bInterval);

ret = usb_submit_urb(usb_data->int_urb, GFP_KERNEL);
@@ -407,7 +411,7 @@ static int nct6694_usb_probe(struct usb_interface *iface,

usb_set_intfdata(iface, ddata);

- ret = mfd_add_hotplug_devices(dev, nct6694_devs, ARRAY_SIZE(nct6694_devs));
+ ret = mfd_add_hotplug_devices(dev, nct6694_usb_devs, ARRAY_SIZE(nct6694_usb_devs));
if (ret)
goto err_mfd;

@@ -441,20 +445,20 @@ static void nct6694_usb_disconnect(struct usb_interface *iface)
usb_free_urb(usb_data->int_urb);
}

-static const struct usb_device_id nct6694_ids[] = {
+static const struct usb_device_id nct6694_usb_ids[] = {
{ USB_DEVICE_AND_INTERFACE_INFO(NCT6694_VENDOR_ID, NCT6694_PRODUCT_ID, 0xFF, 0x00, 0x00) },
{ }
};
-MODULE_DEVICE_TABLE(usb, nct6694_ids);
+MODULE_DEVICE_TABLE(usb, nct6694_usb_ids);

static struct usb_driver nct6694_usb_driver = {
- .name = "nct6694",
- .id_table = nct6694_ids,
+ .name = "nct6694-usb",
+ .id_table = nct6694_usb_ids,
.probe = nct6694_usb_probe,
.disconnect = nct6694_usb_disconnect,
};
module_usb_driver(nct6694_usb_driver);

-MODULE_DESCRIPTION("Nuvoton NCT6694 core driver");
+MODULE_DESCRIPTION("Nuvoton NCT6694 USB transport driver");
MODULE_AUTHOR("Ming Yu <tmyu0@xxxxxxxxxxx>");
MODULE_LICENSE("GPL");
@@ -111,7 +111,7 @@ static int nct6694_response_err_handling(struct nct6694 *ddata, unsigned char er

/**
- * nct6694_read_msg() - Read message from NCT6694 device
+ * nct6694_usb_read_msg() - Read message from NCT6694 device
* @ddata: NCT6694 device pointer
* @cmd_hd: command header structure
@@ -170,12 +172,12 @@ int nct6694_read_msg(struct nct6694 *ddata, const struct nct6694_cmd_header *cmd

/**
- * nct6694_write_msg() - Write message to NCT6694 device
+ * nct6694_usb_write_msg() - Write message to NCT6694 device
* @ddata: NCT6694 device pointer
* @cmd_hd: command header structure
--
2.34.1